Graph utilities
========================

.. automodule:: queueing_tool.graph

   .. autoclass:: QueueNetworkDiGraph
      :show-inheritance:
      :members:

Graph generation
----------------

    .. autofunction:: adjacency2graph
    .. autofunction:: generate_random_graph
    .. autofunction:: generate_pagerank_graph
    .. autofunction:: generate_transition_matrix
    .. autofunction:: minimal_random_graph
    .. autofunction:: set_types_rank
    .. autofunction:: set_types_random

Miscellaneous functions
-----------------------

    .. autofunction:: graph2dict

Exceptions
----------

  .. autoexception:: queueing_tool.network.QueueingToolError
